# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import nidmm_pb2 as nidmm__pb2


class NiDmmStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Abort = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Abort',
                request_serializer=nidmm__pb2.AbortRequest.SerializeToString,
                response_deserializer=nidmm__pb2.AbortResponse.FromString,
                )
        self.CheckAttributeViBoolean = channel.unary_unary(
                '/nidmm_grpc.NiDmm/CheckAttributeViBoolean',
                request_serializer=nidmm__pb2.CheckAttributeViBooleanRequest.SerializeToString,
                response_deserializer=nidmm__pb2.CheckAttributeViBooleanResponse.FromString,
                )
        self.CheckAttributeViInt32 = channel.unary_unary(
                '/nidmm_grpc.NiDmm/CheckAttributeViInt32',
                request_serializer=nidmm__pb2.CheckAttributeViInt32Request.SerializeToString,
                response_deserializer=nidmm__pb2.CheckAttributeViInt32Response.FromString,
                )
        self.CheckAttributeViReal64 = channel.unary_unary(
                '/nidmm_grpc.NiDmm/CheckAttributeViReal64',
                request_serializer=nidmm__pb2.CheckAttributeViReal64Request.SerializeToString,
                response_deserializer=nidmm__pb2.CheckAttributeViReal64Response.FromString,
                )
        self.CheckAttributeViSession = channel.unary_unary(
                '/nidmm_grpc.NiDmm/CheckAttributeViSession',
                request_serializer=nidmm__pb2.CheckAttributeViSessionRequest.SerializeToString,
                response_deserializer=nidmm__pb2.CheckAttributeViSessionResponse.FromString,
                )
        self.CheckAttributeViString = channel.unary_unary(
                '/nidmm_grpc.NiDmm/CheckAttributeViString',
                request_serializer=nidmm__pb2.CheckAttributeViStringRequest.SerializeToString,
                response_deserializer=nidmm__pb2.CheckAttributeViStringResponse.FromString,
                )
        self.ClearError = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ClearError',
                request_serializer=nidmm__pb2.ClearErrorRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ClearErrorResponse.FromString,
                )
        self.ClearInterchangeWarnings = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ClearInterchangeWarnings',
                request_serializer=nidmm__pb2.ClearInterchangeWarningsRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ClearInterchangeWarningsResponse.FromString,
                )
        self.Close = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Close',
                request_serializer=nidmm__pb2.CloseRequest.SerializeToString,
                response_deserializer=nidmm__pb2.CloseResponse.FromString,
                )
        self.ConfigureACBandwidth = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureACBandwidth',
                request_serializer=nidmm__pb2.ConfigureACBandwidthRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureACBandwidthResponse.FromString,
                )
        self.ConfigureADCCalibration = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureADCCalibration',
                request_serializer=nidmm__pb2.ConfigureADCCalibrationRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureADCCalibrationResponse.FromString,
                )
        self.ConfigureAutoZeroMode = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureAutoZeroMode',
                request_serializer=nidmm__pb2.ConfigureAutoZeroModeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureAutoZeroModeResponse.FromString,
                )
        self.ConfigureCableCompType = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureCableCompType',
                request_serializer=nidmm__pb2.ConfigureCableCompTypeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureCableCompTypeResponse.FromString,
                )
        self.ConfigureCurrentSource = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureCurrentSource',
                request_serializer=nidmm__pb2.ConfigureCurrentSourceRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureCurrentSourceResponse.FromString,
                )
        self.ConfigureFixedRefJunction = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureFixedRefJunction',
                request_serializer=nidmm__pb2.ConfigureFixedRefJunctionRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureFixedRefJunctionResponse.FromString,
                )
        self.ConfigureFrequencyVoltageRange = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureFrequencyVoltageRange',
                request_serializer=nidmm__pb2.ConfigureFrequencyVoltageRangeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureFrequencyVoltageRangeResponse.FromString,
                )
        self.ConfigureMeasCompleteDest = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureMeasCompleteDest',
                request_serializer=nidmm__pb2.ConfigureMeasCompleteDestRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureMeasCompleteDestResponse.FromString,
                )
        self.ConfigureMeasCompleteSlope = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureMeasCompleteSlope',
                request_serializer=nidmm__pb2.ConfigureMeasCompleteSlopeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureMeasCompleteSlopeResponse.FromString,
                )
        self.ConfigureMeasurementAbsolute = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureMeasurementAbsolute',
                request_serializer=nidmm__pb2.ConfigureMeasurementAbsoluteRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureMeasurementAbsoluteResponse.FromString,
                )
        self.ConfigureMeasurementDigits = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureMeasurementDigits',
                request_serializer=nidmm__pb2.ConfigureMeasurementDigitsRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureMeasurementDigitsResponse.FromString,
                )
        self.ConfigureMultiPoint = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureMultiPoint',
                request_serializer=nidmm__pb2.ConfigureMultiPointRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureMultiPointResponse.FromString,
                )
        self.ConfigureOffsetCompOhms = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureOffsetCompOhms',
                request_serializer=nidmm__pb2.ConfigureOffsetCompOhmsRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureOffsetCompOhmsResponse.FromString,
                )
        self.ConfigureOpenCableCompValues = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureOpenCableCompValues',
                request_serializer=nidmm__pb2.ConfigureOpenCableCompValuesRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureOpenCableCompValuesResponse.FromString,
                )
        self.ConfigurePowerLineFrequency = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigurePowerLineFrequency',
                request_serializer=nidmm__pb2.ConfigurePowerLineFrequencyRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigurePowerLineFrequencyResponse.FromString,
                )
        self.ConfigureRTDCustom = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureRTDCustom',
                request_serializer=nidmm__pb2.ConfigureRTDCustomRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureRTDCustomResponse.FromString,
                )
        self.ConfigureRTDType = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureRTDType',
                request_serializer=nidmm__pb2.ConfigureRTDTypeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureRTDTypeResponse.FromString,
                )
        self.ConfigureSampleTriggerSlope = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureSampleTriggerSlope',
                request_serializer=nidmm__pb2.ConfigureSampleTriggerSlopeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureSampleTriggerSlopeResponse.FromString,
                )
        self.ConfigureShortCableCompValues = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureShortCableCompValues',
                request_serializer=nidmm__pb2.ConfigureShortCableCompValuesRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureShortCableCompValuesResponse.FromString,
                )
        self.ConfigureThermistorCustom = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureThermistorCustom',
                request_serializer=nidmm__pb2.ConfigureThermistorCustomRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureThermistorCustomResponse.FromString,
                )
        self.ConfigureThermistorType = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureThermistorType',
                request_serializer=nidmm__pb2.ConfigureThermistorTypeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureThermistorTypeResponse.FromString,
                )
        self.ConfigureThermocouple = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureThermocouple',
                request_serializer=nidmm__pb2.ConfigureThermocoupleRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureThermocoupleResponse.FromString,
                )
        self.ConfigureTransducerType = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureTransducerType',
                request_serializer=nidmm__pb2.ConfigureTransducerTypeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureTransducerTypeResponse.FromString,
                )
        self.ConfigureTrigger = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureTrigger',
                request_serializer=nidmm__pb2.ConfigureTriggerRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureTriggerResponse.FromString,
                )
        self.ConfigureTriggerSlope = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureTriggerSlope',
                request_serializer=nidmm__pb2.ConfigureTriggerSlopeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureTriggerSlopeResponse.FromString,
                )
        self.ConfigureWaveformAcquisition = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureWaveformAcquisition',
                request_serializer=nidmm__pb2.ConfigureWaveformAcquisitionRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureWaveformAcquisitionResponse.FromString,
                )
        self.ConfigureWaveformCoupling = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ConfigureWaveformCoupling',
                request_serializer=nidmm__pb2.ConfigureWaveformCouplingRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ConfigureWaveformCouplingResponse.FromString,
                )
        self.Control = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Control',
                request_serializer=nidmm__pb2.ControlRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ControlResponse.FromString,
                )
        self.Disable = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Disable',
                request_serializer=nidmm__pb2.DisableRequest.SerializeToString,
                response_deserializer=nidmm__pb2.DisableResponse.FromString,
                )
        self.ExportAttributeConfigurationBuffer = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ExportAttributeConfigurationBuffer',
                request_serializer=nidmm__pb2.ExportAttributeConfigurationBufferRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ExportAttributeConfigurationBufferResponse.FromString,
                )
        self.ExportAttributeConfigurationFile = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ExportAttributeConfigurationFile',
                request_serializer=nidmm__pb2.ExportAttributeConfigurationFileRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ExportAttributeConfigurationFileResponse.FromString,
                )
        self.Fetch = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Fetch',
                request_serializer=nidmm__pb2.FetchRequest.SerializeToString,
                response_deserializer=nidmm__pb2.FetchResponse.FromString,
                )
        self.FetchMultiPoint = channel.unary_unary(
                '/nidmm_grpc.NiDmm/FetchMultiPoint',
                request_serializer=nidmm__pb2.FetchMultiPointRequest.SerializeToString,
                response_deserializer=nidmm__pb2.FetchMultiPointResponse.FromString,
                )
        self.FetchWaveform = channel.unary_unary(
                '/nidmm_grpc.NiDmm/FetchWaveform',
                request_serializer=nidmm__pb2.FetchWaveformRequest.SerializeToString,
                response_deserializer=nidmm__pb2.FetchWaveformResponse.FromString,
                )
        self.GetApertureTimeInfo = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetApertureTimeInfo',
                request_serializer=nidmm__pb2.GetApertureTimeInfoRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetApertureTimeInfoResponse.FromString,
                )
        self.GetAttributeViBoolean = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetAttributeViBoolean',
                request_serializer=nidmm__pb2.GetAttributeViBooleanRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetAttributeViBooleanResponse.FromString,
                )
        self.GetAttributeViInt32 = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetAttributeViInt32',
                request_serializer=nidmm__pb2.GetAttributeViInt32Request.SerializeToString,
                response_deserializer=nidmm__pb2.GetAttributeViInt32Response.FromString,
                )
        self.GetAttributeViReal64 = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetAttributeViReal64',
                request_serializer=nidmm__pb2.GetAttributeViReal64Request.SerializeToString,
                response_deserializer=nidmm__pb2.GetAttributeViReal64Response.FromString,
                )
        self.GetAttributeViSession = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetAttributeViSession',
                request_serializer=nidmm__pb2.GetAttributeViSessionRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetAttributeViSessionResponse.FromString,
                )
        self.GetAttributeViString = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetAttributeViString',
                request_serializer=nidmm__pb2.GetAttributeViStringRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetAttributeViStringResponse.FromString,
                )
        self.GetAutoRangeValue = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetAutoRangeValue',
                request_serializer=nidmm__pb2.GetAutoRangeValueRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetAutoRangeValueResponse.FromString,
                )
        self.GetCalDateAndTime = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetCalDateAndTime',
                request_serializer=nidmm__pb2.GetCalDateAndTimeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetCalDateAndTimeResponse.FromString,
                )
        self.GetChannelName = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetChannelName',
                request_serializer=nidmm__pb2.GetChannelNameRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetChannelNameResponse.FromString,
                )
        self.GetDevTemp = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetDevTemp',
                request_serializer=nidmm__pb2.GetDevTempRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetDevTempResponse.FromString,
                )
        self.GetError = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetError',
                request_serializer=nidmm__pb2.GetErrorRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetErrorResponse.FromString,
                )
        self.GetErrorMessage = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetErrorMessage',
                request_serializer=nidmm__pb2.GetErrorMessageRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetErrorMessageResponse.FromString,
                )
        self.GetExtCalRecommendedInterval = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetExtCalRecommendedInterval',
                request_serializer=nidmm__pb2.GetExtCalRecommendedIntervalRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetExtCalRecommendedIntervalResponse.FromString,
                )
        self.GetLastCalTemp = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetLastCalTemp',
                request_serializer=nidmm__pb2.GetLastCalTempRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetLastCalTempResponse.FromString,
                )
        self.GetMeasurementPeriod = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetMeasurementPeriod',
                request_serializer=nidmm__pb2.GetMeasurementPeriodRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetMeasurementPeriodResponse.FromString,
                )
        self.GetNextCoercionRecord = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetNextCoercionRecord',
                request_serializer=nidmm__pb2.GetNextCoercionRecordRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetNextCoercionRecordResponse.FromString,
                )
        self.GetNextInterchangeWarning = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetNextInterchangeWarning',
                request_serializer=nidmm__pb2.GetNextInterchangeWarningRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetNextInterchangeWarningResponse.FromString,
                )
        self.GetSelfCalSupported = channel.unary_unary(
                '/nidmm_grpc.NiDmm/GetSelfCalSupported',
                request_serializer=nidmm__pb2.GetSelfCalSupportedRequest.SerializeToString,
                response_deserializer=nidmm__pb2.GetSelfCalSupportedResponse.FromString,
                )
        self.ImportAttributeConfigurationBuffer = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ImportAttributeConfigurationBuffer',
                request_serializer=nidmm__pb2.ImportAttributeConfigurationBufferRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ImportAttributeConfigurationBufferResponse.FromString,
                )
        self.ImportAttributeConfigurationFile = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ImportAttributeConfigurationFile',
                request_serializer=nidmm__pb2.ImportAttributeConfigurationFileRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ImportAttributeConfigurationFileResponse.FromString,
                )
        self.Init = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Init',
                request_serializer=nidmm__pb2.InitRequest.SerializeToString,
                response_deserializer=nidmm__pb2.InitResponse.FromString,
                )
        self.InitWithOptions = channel.unary_unary(
                '/nidmm_grpc.NiDmm/InitWithOptions',
                request_serializer=nidmm__pb2.InitWithOptionsRequest.SerializeToString,
                response_deserializer=nidmm__pb2.InitWithOptionsResponse.FromString,
                )
        self.Initiate = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Initiate',
                request_serializer=nidmm__pb2.InitiateRequest.SerializeToString,
                response_deserializer=nidmm__pb2.InitiateResponse.FromString,
                )
        self.InvalidateAllAttributes = channel.unary_unary(
                '/nidmm_grpc.NiDmm/InvalidateAllAttributes',
                request_serializer=nidmm__pb2.InvalidateAllAttributesRequest.SerializeToString,
                response_deserializer=nidmm__pb2.InvalidateAllAttributesResponse.FromString,
                )
        self.IsOverRange = channel.unary_unary(
                '/nidmm_grpc.NiDmm/IsOverRange',
                request_serializer=nidmm__pb2.IsOverRangeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.IsOverRangeResponse.FromString,
                )
        self.IsUnderRange = channel.unary_unary(
                '/nidmm_grpc.NiDmm/IsUnderRange',
                request_serializer=nidmm__pb2.IsUnderRangeRequest.SerializeToString,
                response_deserializer=nidmm__pb2.IsUnderRangeResponse.FromString,
                )
        self.PerformOpenCableComp = channel.unary_unary(
                '/nidmm_grpc.NiDmm/PerformOpenCableComp',
                request_serializer=nidmm__pb2.PerformOpenCableCompRequest.SerializeToString,
                response_deserializer=nidmm__pb2.PerformOpenCableCompResponse.FromString,
                )
        self.PerformShortCableComp = channel.unary_unary(
                '/nidmm_grpc.NiDmm/PerformShortCableComp',
                request_serializer=nidmm__pb2.PerformShortCableCompRequest.SerializeToString,
                response_deserializer=nidmm__pb2.PerformShortCableCompResponse.FromString,
                )
        self.Read = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Read',
                request_serializer=nidmm__pb2.ReadRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ReadResponse.FromString,
                )
        self.ReadMultiPoint = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ReadMultiPoint',
                request_serializer=nidmm__pb2.ReadMultiPointRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ReadMultiPointResponse.FromString,
                )
        self.ReadStatus = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ReadStatus',
                request_serializer=nidmm__pb2.ReadStatusRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ReadStatusResponse.FromString,
                )
        self.ReadWaveform = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ReadWaveform',
                request_serializer=nidmm__pb2.ReadWaveformRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ReadWaveformResponse.FromString,
                )
        self.Reset = channel.unary_unary(
                '/nidmm_grpc.NiDmm/Reset',
                request_serializer=nidmm__pb2.ResetRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ResetResponse.FromString,
                )
        self.ResetInterchangeCheck = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ResetInterchangeCheck',
                request_serializer=nidmm__pb2.ResetInterchangeCheckRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ResetInterchangeCheckResponse.FromString,
                )
        self.ResetWithDefaults = channel.unary_unary(
                '/nidmm_grpc.NiDmm/ResetWithDefaults',
                request_serializer=nidmm__pb2.ResetWithDefaultsRequest.SerializeToString,
                response_deserializer=nidmm__pb2.ResetWithDefaultsResponse.FromString,
                )
        self.RevisionQuery = channel.unary_unary(
                '/nidmm_grpc.NiDmm/RevisionQuery',
                request_serializer=nidmm__pb2.RevisionQueryRequest.SerializeToString,
                response_deserializer=nidmm__pb2.RevisionQueryResponse.FromString,
                )
        self.SelfCal = channel.unary_unary(
                '/nidmm_grpc.NiDmm/SelfCal',
                request_serializer=nidmm__pb2.SelfCalRequest.SerializeToString,
                response_deserializer=nidmm__pb2.SelfCalResponse.FromString,
                )
        self.SelfTest = channel.unary_unary(
                '/nidmm_grpc.NiDmm/SelfTest',
                request_serializer=nidmm__pb2.SelfTestRequest.SerializeToString,
                response_deserializer=nidmm__pb2.SelfTestResponse.FromString,
                )
        self.SendSoftwareTrigger = channel.unary_unary(
                '/nidmm_grpc.NiDmm/SendSoftwareTrigger',
                request_serializer=nidmm__pb2.SendSoftwareTriggerRequest.SerializeToString,
                response_deserializer=nidmm__pb2.SendSoftwareTriggerResponse.FromString,
                )
        self.SetAttributeViBoolean = channel.unary_unary(
                '/nidmm_grpc.NiDmm/SetAttributeViBoolean',
                request_serializer=nidmm__pb2.SetAttributeViBooleanRequest.SerializeToString,
                response_deserializer=nidmm__pb2.SetAttributeViBooleanResponse.FromString,
                )
        self.SetAttributeViInt32 = channel.unary_unary(
                '/nidmm_grpc.NiDmm/SetAttributeViInt32',
                request_serializer=nidmm__pb2.SetAttributeViInt32Request.SerializeToString,
                response_deserializer=nidmm__pb2.SetAttributeViInt32Response.FromString,
                )
        self.SetAttributeViReal64 = channel.unary_unary(
                '/nidmm_grpc.NiDmm/SetAttributeViReal64',
                request_serializer=nidmm__pb2.SetAttributeViReal64Request.SerializeToString,
                response_deserializer=nidmm__pb2.SetAttributeViReal64Response.FromString,
                )
        self.SetAttributeViSession = channel.unary_unary(
                '/nidmm_grpc.NiDmm/SetAttributeViSession',
                request_serializer=nidmm__pb2.SetAttributeViSessionRequest.SerializeToString,
                response_deserializer=nidmm__pb2.SetAttributeViSessionResponse.FromString,
                )
        self.SetAttributeViString = channel.unary_unary(
                '/nidmm_grpc.NiDmm/SetAttributeViString',
                request_serializer=nidmm__pb2.SetAttributeViStringRequest.SerializeToString,
                response_deserializer=nidmm__pb2.SetAttributeViStringResponse.FromString,
                )


class NiDmmServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Abort(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViBoolean(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViInt32(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViReal64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CheckAttributeViString(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearError(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ClearInterchangeWarnings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Close(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureACBandwidth(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureADCCalibration(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureAutoZeroMode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureCableCompType(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureCurrentSource(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureFixedRefJunction(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureFrequencyVoltageRange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureMeasCompleteDest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureMeasCompleteSlope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureMeasurementAbsolute(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureMeasurementDigits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureMultiPoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureOffsetCompOhms(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureOpenCableCompValues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigurePowerLineFrequency(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureRTDCustom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureRTDType(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureSampleTriggerSlope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureShortCableCompValues(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureThermistorCustom(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureThermistorType(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureThermocouple(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureTransducerType(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureTriggerSlope(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureWaveformAcquisition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConfigureWaveformCoupling(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Control(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Disable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportAttributeConfigurationBuffer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportAttributeConfigurationFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Fetch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchMultiPoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FetchWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApertureTimeInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViBoolean(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViInt32(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViReal64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAttributeViString(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAutoRangeValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetCalDateAndTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChannelName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDevTemp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetError(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetErrorMessage(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetExtCalRecommendedInterval(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLastCalTemp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMeasurementPeriod(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNextCoercionRecord(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNextInterchangeWarning(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSelfCalSupported(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportAttributeConfigurationBuffer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ImportAttributeConfigurationFile(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Init(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitWithOptions(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Initiate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvalidateAllAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsOverRange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IsUnderRange(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PerformOpenCableComp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PerformShortCableComp(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Read(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadMultiPoint(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadStatus(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadWaveform(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reset(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetInterchangeCheck(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetWithDefaults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevisionQuery(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SelfCal(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SelfTest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendSoftwareTrigger(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViBoolean(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViInt32(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViReal64(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViSession(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAttributeViString(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NiDmmServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Abort': grpc.unary_unary_rpc_method_handler(
                    servicer.Abort,
                    request_deserializer=nidmm__pb2.AbortRequest.FromString,
                    response_serializer=nidmm__pb2.AbortResponse.SerializeToString,
            ),
            'CheckAttributeViBoolean': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViBoolean,
                    request_deserializer=nidmm__pb2.CheckAttributeViBooleanRequest.FromString,
                    response_serializer=nidmm__pb2.CheckAttributeViBooleanResponse.SerializeToString,
            ),
            'CheckAttributeViInt32': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViInt32,
                    request_deserializer=nidmm__pb2.CheckAttributeViInt32Request.FromString,
                    response_serializer=nidmm__pb2.CheckAttributeViInt32Response.SerializeToString,
            ),
            'CheckAttributeViReal64': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViReal64,
                    request_deserializer=nidmm__pb2.CheckAttributeViReal64Request.FromString,
                    response_serializer=nidmm__pb2.CheckAttributeViReal64Response.SerializeToString,
            ),
            'CheckAttributeViSession': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViSession,
                    request_deserializer=nidmm__pb2.CheckAttributeViSessionRequest.FromString,
                    response_serializer=nidmm__pb2.CheckAttributeViSessionResponse.SerializeToString,
            ),
            'CheckAttributeViString': grpc.unary_unary_rpc_method_handler(
                    servicer.CheckAttributeViString,
                    request_deserializer=nidmm__pb2.CheckAttributeViStringRequest.FromString,
                    response_serializer=nidmm__pb2.CheckAttributeViStringResponse.SerializeToString,
            ),
            'ClearError': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearError,
                    request_deserializer=nidmm__pb2.ClearErrorRequest.FromString,
                    response_serializer=nidmm__pb2.ClearErrorResponse.SerializeToString,
            ),
            'ClearInterchangeWarnings': grpc.unary_unary_rpc_method_handler(
                    servicer.ClearInterchangeWarnings,
                    request_deserializer=nidmm__pb2.ClearInterchangeWarningsRequest.FromString,
                    response_serializer=nidmm__pb2.ClearInterchangeWarningsResponse.SerializeToString,
            ),
            'Close': grpc.unary_unary_rpc_method_handler(
                    servicer.Close,
                    request_deserializer=nidmm__pb2.CloseRequest.FromString,
                    response_serializer=nidmm__pb2.CloseResponse.SerializeToString,
            ),
            'ConfigureACBandwidth': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureACBandwidth,
                    request_deserializer=nidmm__pb2.ConfigureACBandwidthRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureACBandwidthResponse.SerializeToString,
            ),
            'ConfigureADCCalibration': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureADCCalibration,
                    request_deserializer=nidmm__pb2.ConfigureADCCalibrationRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureADCCalibrationResponse.SerializeToString,
            ),
            'ConfigureAutoZeroMode': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureAutoZeroMode,
                    request_deserializer=nidmm__pb2.ConfigureAutoZeroModeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureAutoZeroModeResponse.SerializeToString,
            ),
            'ConfigureCableCompType': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureCableCompType,
                    request_deserializer=nidmm__pb2.ConfigureCableCompTypeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureCableCompTypeResponse.SerializeToString,
            ),
            'ConfigureCurrentSource': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureCurrentSource,
                    request_deserializer=nidmm__pb2.ConfigureCurrentSourceRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureCurrentSourceResponse.SerializeToString,
            ),
            'ConfigureFixedRefJunction': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureFixedRefJunction,
                    request_deserializer=nidmm__pb2.ConfigureFixedRefJunctionRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureFixedRefJunctionResponse.SerializeToString,
            ),
            'ConfigureFrequencyVoltageRange': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureFrequencyVoltageRange,
                    request_deserializer=nidmm__pb2.ConfigureFrequencyVoltageRangeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureFrequencyVoltageRangeResponse.SerializeToString,
            ),
            'ConfigureMeasCompleteDest': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureMeasCompleteDest,
                    request_deserializer=nidmm__pb2.ConfigureMeasCompleteDestRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureMeasCompleteDestResponse.SerializeToString,
            ),
            'ConfigureMeasCompleteSlope': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureMeasCompleteSlope,
                    request_deserializer=nidmm__pb2.ConfigureMeasCompleteSlopeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureMeasCompleteSlopeResponse.SerializeToString,
            ),
            'ConfigureMeasurementAbsolute': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureMeasurementAbsolute,
                    request_deserializer=nidmm__pb2.ConfigureMeasurementAbsoluteRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureMeasurementAbsoluteResponse.SerializeToString,
            ),
            'ConfigureMeasurementDigits': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureMeasurementDigits,
                    request_deserializer=nidmm__pb2.ConfigureMeasurementDigitsRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureMeasurementDigitsResponse.SerializeToString,
            ),
            'ConfigureMultiPoint': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureMultiPoint,
                    request_deserializer=nidmm__pb2.ConfigureMultiPointRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureMultiPointResponse.SerializeToString,
            ),
            'ConfigureOffsetCompOhms': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureOffsetCompOhms,
                    request_deserializer=nidmm__pb2.ConfigureOffsetCompOhmsRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureOffsetCompOhmsResponse.SerializeToString,
            ),
            'ConfigureOpenCableCompValues': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureOpenCableCompValues,
                    request_deserializer=nidmm__pb2.ConfigureOpenCableCompValuesRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureOpenCableCompValuesResponse.SerializeToString,
            ),
            'ConfigurePowerLineFrequency': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigurePowerLineFrequency,
                    request_deserializer=nidmm__pb2.ConfigurePowerLineFrequencyRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigurePowerLineFrequencyResponse.SerializeToString,
            ),
            'ConfigureRTDCustom': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureRTDCustom,
                    request_deserializer=nidmm__pb2.ConfigureRTDCustomRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureRTDCustomResponse.SerializeToString,
            ),
            'ConfigureRTDType': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureRTDType,
                    request_deserializer=nidmm__pb2.ConfigureRTDTypeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureRTDTypeResponse.SerializeToString,
            ),
            'ConfigureSampleTriggerSlope': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureSampleTriggerSlope,
                    request_deserializer=nidmm__pb2.ConfigureSampleTriggerSlopeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureSampleTriggerSlopeResponse.SerializeToString,
            ),
            'ConfigureShortCableCompValues': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureShortCableCompValues,
                    request_deserializer=nidmm__pb2.ConfigureShortCableCompValuesRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureShortCableCompValuesResponse.SerializeToString,
            ),
            'ConfigureThermistorCustom': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureThermistorCustom,
                    request_deserializer=nidmm__pb2.ConfigureThermistorCustomRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureThermistorCustomResponse.SerializeToString,
            ),
            'ConfigureThermistorType': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureThermistorType,
                    request_deserializer=nidmm__pb2.ConfigureThermistorTypeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureThermistorTypeResponse.SerializeToString,
            ),
            'ConfigureThermocouple': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureThermocouple,
                    request_deserializer=nidmm__pb2.ConfigureThermocoupleRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureThermocoupleResponse.SerializeToString,
            ),
            'ConfigureTransducerType': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureTransducerType,
                    request_deserializer=nidmm__pb2.ConfigureTransducerTypeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureTransducerTypeResponse.SerializeToString,
            ),
            'ConfigureTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureTrigger,
                    request_deserializer=nidmm__pb2.ConfigureTriggerRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureTriggerResponse.SerializeToString,
            ),
            'ConfigureTriggerSlope': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureTriggerSlope,
                    request_deserializer=nidmm__pb2.ConfigureTriggerSlopeRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureTriggerSlopeResponse.SerializeToString,
            ),
            'ConfigureWaveformAcquisition': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureWaveformAcquisition,
                    request_deserializer=nidmm__pb2.ConfigureWaveformAcquisitionRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureWaveformAcquisitionResponse.SerializeToString,
            ),
            'ConfigureWaveformCoupling': grpc.unary_unary_rpc_method_handler(
                    servicer.ConfigureWaveformCoupling,
                    request_deserializer=nidmm__pb2.ConfigureWaveformCouplingRequest.FromString,
                    response_serializer=nidmm__pb2.ConfigureWaveformCouplingResponse.SerializeToString,
            ),
            'Control': grpc.unary_unary_rpc_method_handler(
                    servicer.Control,
                    request_deserializer=nidmm__pb2.ControlRequest.FromString,
                    response_serializer=nidmm__pb2.ControlResponse.SerializeToString,
            ),
            'Disable': grpc.unary_unary_rpc_method_handler(
                    servicer.Disable,
                    request_deserializer=nidmm__pb2.DisableRequest.FromString,
                    response_serializer=nidmm__pb2.DisableResponse.SerializeToString,
            ),
            'ExportAttributeConfigurationBuffer': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportAttributeConfigurationBuffer,
                    request_deserializer=nidmm__pb2.ExportAttributeConfigurationBufferRequest.FromString,
                    response_serializer=nidmm__pb2.ExportAttributeConfigurationBufferResponse.SerializeToString,
            ),
            'ExportAttributeConfigurationFile': grpc.unary_unary_rpc_method_handler(
                    servicer.ExportAttributeConfigurationFile,
                    request_deserializer=nidmm__pb2.ExportAttributeConfigurationFileRequest.FromString,
                    response_serializer=nidmm__pb2.ExportAttributeConfigurationFileResponse.SerializeToString,
            ),
            'Fetch': grpc.unary_unary_rpc_method_handler(
                    servicer.Fetch,
                    request_deserializer=nidmm__pb2.FetchRequest.FromString,
                    response_serializer=nidmm__pb2.FetchResponse.SerializeToString,
            ),
            'FetchMultiPoint': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchMultiPoint,
                    request_deserializer=nidmm__pb2.FetchMultiPointRequest.FromString,
                    response_serializer=nidmm__pb2.FetchMultiPointResponse.SerializeToString,
            ),
            'FetchWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.FetchWaveform,
                    request_deserializer=nidmm__pb2.FetchWaveformRequest.FromString,
                    response_serializer=nidmm__pb2.FetchWaveformResponse.SerializeToString,
            ),
            'GetApertureTimeInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApertureTimeInfo,
                    request_deserializer=nidmm__pb2.GetApertureTimeInfoRequest.FromString,
                    response_serializer=nidmm__pb2.GetApertureTimeInfoResponse.SerializeToString,
            ),
            'GetAttributeViBoolean': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViBoolean,
                    request_deserializer=nidmm__pb2.GetAttributeViBooleanRequest.FromString,
                    response_serializer=nidmm__pb2.GetAttributeViBooleanResponse.SerializeToString,
            ),
            'GetAttributeViInt32': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViInt32,
                    request_deserializer=nidmm__pb2.GetAttributeViInt32Request.FromString,
                    response_serializer=nidmm__pb2.GetAttributeViInt32Response.SerializeToString,
            ),
            'GetAttributeViReal64': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViReal64,
                    request_deserializer=nidmm__pb2.GetAttributeViReal64Request.FromString,
                    response_serializer=nidmm__pb2.GetAttributeViReal64Response.SerializeToString,
            ),
            'GetAttributeViSession': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViSession,
                    request_deserializer=nidmm__pb2.GetAttributeViSessionRequest.FromString,
                    response_serializer=nidmm__pb2.GetAttributeViSessionResponse.SerializeToString,
            ),
            'GetAttributeViString': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAttributeViString,
                    request_deserializer=nidmm__pb2.GetAttributeViStringRequest.FromString,
                    response_serializer=nidmm__pb2.GetAttributeViStringResponse.SerializeToString,
            ),
            'GetAutoRangeValue': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAutoRangeValue,
                    request_deserializer=nidmm__pb2.GetAutoRangeValueRequest.FromString,
                    response_serializer=nidmm__pb2.GetAutoRangeValueResponse.SerializeToString,
            ),
            'GetCalDateAndTime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetCalDateAndTime,
                    request_deserializer=nidmm__pb2.GetCalDateAndTimeRequest.FromString,
                    response_serializer=nidmm__pb2.GetCalDateAndTimeResponse.SerializeToString,
            ),
            'GetChannelName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChannelName,
                    request_deserializer=nidmm__pb2.GetChannelNameRequest.FromString,
                    response_serializer=nidmm__pb2.GetChannelNameResponse.SerializeToString,
            ),
            'GetDevTemp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDevTemp,
                    request_deserializer=nidmm__pb2.GetDevTempRequest.FromString,
                    response_serializer=nidmm__pb2.GetDevTempResponse.SerializeToString,
            ),
            'GetError': grpc.unary_unary_rpc_method_handler(
                    servicer.GetError,
                    request_deserializer=nidmm__pb2.GetErrorRequest.FromString,
                    response_serializer=nidmm__pb2.GetErrorResponse.SerializeToString,
            ),
            'GetErrorMessage': grpc.unary_unary_rpc_method_handler(
                    servicer.GetErrorMessage,
                    request_deserializer=nidmm__pb2.GetErrorMessageRequest.FromString,
                    response_serializer=nidmm__pb2.GetErrorMessageResponse.SerializeToString,
            ),
            'GetExtCalRecommendedInterval': grpc.unary_unary_rpc_method_handler(
                    servicer.GetExtCalRecommendedInterval,
                    request_deserializer=nidmm__pb2.GetExtCalRecommendedIntervalRequest.FromString,
                    response_serializer=nidmm__pb2.GetExtCalRecommendedIntervalResponse.SerializeToString,
            ),
            'GetLastCalTemp': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLastCalTemp,
                    request_deserializer=nidmm__pb2.GetLastCalTempRequest.FromString,
                    response_serializer=nidmm__pb2.GetLastCalTempResponse.SerializeToString,
            ),
            'GetMeasurementPeriod': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMeasurementPeriod,
                    request_deserializer=nidmm__pb2.GetMeasurementPeriodRequest.FromString,
                    response_serializer=nidmm__pb2.GetMeasurementPeriodResponse.SerializeToString,
            ),
            'GetNextCoercionRecord': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNextCoercionRecord,
                    request_deserializer=nidmm__pb2.GetNextCoercionRecordRequest.FromString,
                    response_serializer=nidmm__pb2.GetNextCoercionRecordResponse.SerializeToString,
            ),
            'GetNextInterchangeWarning': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNextInterchangeWarning,
                    request_deserializer=nidmm__pb2.GetNextInterchangeWarningRequest.FromString,
                    response_serializer=nidmm__pb2.GetNextInterchangeWarningResponse.SerializeToString,
            ),
            'GetSelfCalSupported': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSelfCalSupported,
                    request_deserializer=nidmm__pb2.GetSelfCalSupportedRequest.FromString,
                    response_serializer=nidmm__pb2.GetSelfCalSupportedResponse.SerializeToString,
            ),
            'ImportAttributeConfigurationBuffer': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportAttributeConfigurationBuffer,
                    request_deserializer=nidmm__pb2.ImportAttributeConfigurationBufferRequest.FromString,
                    response_serializer=nidmm__pb2.ImportAttributeConfigurationBufferResponse.SerializeToString,
            ),
            'ImportAttributeConfigurationFile': grpc.unary_unary_rpc_method_handler(
                    servicer.ImportAttributeConfigurationFile,
                    request_deserializer=nidmm__pb2.ImportAttributeConfigurationFileRequest.FromString,
                    response_serializer=nidmm__pb2.ImportAttributeConfigurationFileResponse.SerializeToString,
            ),
            'Init': grpc.unary_unary_rpc_method_handler(
                    servicer.Init,
                    request_deserializer=nidmm__pb2.InitRequest.FromString,
                    response_serializer=nidmm__pb2.InitResponse.SerializeToString,
            ),
            'InitWithOptions': grpc.unary_unary_rpc_method_handler(
                    servicer.InitWithOptions,
                    request_deserializer=nidmm__pb2.InitWithOptionsRequest.FromString,
                    response_serializer=nidmm__pb2.InitWithOptionsResponse.SerializeToString,
            ),
            'Initiate': grpc.unary_unary_rpc_method_handler(
                    servicer.Initiate,
                    request_deserializer=nidmm__pb2.InitiateRequest.FromString,
                    response_serializer=nidmm__pb2.InitiateResponse.SerializeToString,
            ),
            'InvalidateAllAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.InvalidateAllAttributes,
                    request_deserializer=nidmm__pb2.InvalidateAllAttributesRequest.FromString,
                    response_serializer=nidmm__pb2.InvalidateAllAttributesResponse.SerializeToString,
            ),
            'IsOverRange': grpc.unary_unary_rpc_method_handler(
                    servicer.IsOverRange,
                    request_deserializer=nidmm__pb2.IsOverRangeRequest.FromString,
                    response_serializer=nidmm__pb2.IsOverRangeResponse.SerializeToString,
            ),
            'IsUnderRange': grpc.unary_unary_rpc_method_handler(
                    servicer.IsUnderRange,
                    request_deserializer=nidmm__pb2.IsUnderRangeRequest.FromString,
                    response_serializer=nidmm__pb2.IsUnderRangeResponse.SerializeToString,
            ),
            'PerformOpenCableComp': grpc.unary_unary_rpc_method_handler(
                    servicer.PerformOpenCableComp,
                    request_deserializer=nidmm__pb2.PerformOpenCableCompRequest.FromString,
                    response_serializer=nidmm__pb2.PerformOpenCableCompResponse.SerializeToString,
            ),
            'PerformShortCableComp': grpc.unary_unary_rpc_method_handler(
                    servicer.PerformShortCableComp,
                    request_deserializer=nidmm__pb2.PerformShortCableCompRequest.FromString,
                    response_serializer=nidmm__pb2.PerformShortCableCompResponse.SerializeToString,
            ),
            'Read': grpc.unary_unary_rpc_method_handler(
                    servicer.Read,
                    request_deserializer=nidmm__pb2.ReadRequest.FromString,
                    response_serializer=nidmm__pb2.ReadResponse.SerializeToString,
            ),
            'ReadMultiPoint': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadMultiPoint,
                    request_deserializer=nidmm__pb2.ReadMultiPointRequest.FromString,
                    response_serializer=nidmm__pb2.ReadMultiPointResponse.SerializeToString,
            ),
            'ReadStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadStatus,
                    request_deserializer=nidmm__pb2.ReadStatusRequest.FromString,
                    response_serializer=nidmm__pb2.ReadStatusResponse.SerializeToString,
            ),
            'ReadWaveform': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadWaveform,
                    request_deserializer=nidmm__pb2.ReadWaveformRequest.FromString,
                    response_serializer=nidmm__pb2.ReadWaveformResponse.SerializeToString,
            ),
            'Reset': grpc.unary_unary_rpc_method_handler(
                    servicer.Reset,
                    request_deserializer=nidmm__pb2.ResetRequest.FromString,
                    response_serializer=nidmm__pb2.ResetResponse.SerializeToString,
            ),
            'ResetInterchangeCheck': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetInterchangeCheck,
                    request_deserializer=nidmm__pb2.ResetInterchangeCheckRequest.FromString,
                    response_serializer=nidmm__pb2.ResetInterchangeCheckResponse.SerializeToString,
            ),
            'ResetWithDefaults': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetWithDefaults,
                    request_deserializer=nidmm__pb2.ResetWithDefaultsRequest.FromString,
                    response_serializer=nidmm__pb2.ResetWithDefaultsResponse.SerializeToString,
            ),
            'RevisionQuery': grpc.unary_unary_rpc_method_handler(
                    servicer.RevisionQuery,
                    request_deserializer=nidmm__pb2.RevisionQueryRequest.FromString,
                    response_serializer=nidmm__pb2.RevisionQueryResponse.SerializeToString,
            ),
            'SelfCal': grpc.unary_unary_rpc_method_handler(
                    servicer.SelfCal,
                    request_deserializer=nidmm__pb2.SelfCalRequest.FromString,
                    response_serializer=nidmm__pb2.SelfCalResponse.SerializeToString,
            ),
            'SelfTest': grpc.unary_unary_rpc_method_handler(
                    servicer.SelfTest,
                    request_deserializer=nidmm__pb2.SelfTestRequest.FromString,
                    response_serializer=nidmm__pb2.SelfTestResponse.SerializeToString,
            ),
            'SendSoftwareTrigger': grpc.unary_unary_rpc_method_handler(
                    servicer.SendSoftwareTrigger,
                    request_deserializer=nidmm__pb2.SendSoftwareTriggerRequest.FromString,
                    response_serializer=nidmm__pb2.SendSoftwareTriggerResponse.SerializeToString,
            ),
            'SetAttributeViBoolean': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViBoolean,
                    request_deserializer=nidmm__pb2.SetAttributeViBooleanRequest.FromString,
                    response_serializer=nidmm__pb2.SetAttributeViBooleanResponse.SerializeToString,
            ),
            'SetAttributeViInt32': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViInt32,
                    request_deserializer=nidmm__pb2.SetAttributeViInt32Request.FromString,
                    response_serializer=nidmm__pb2.SetAttributeViInt32Response.SerializeToString,
            ),
            'SetAttributeViReal64': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViReal64,
                    request_deserializer=nidmm__pb2.SetAttributeViReal64Request.FromString,
                    response_serializer=nidmm__pb2.SetAttributeViReal64Response.SerializeToString,
            ),
            'SetAttributeViSession': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViSession,
                    request_deserializer=nidmm__pb2.SetAttributeViSessionRequest.FromString,
                    response_serializer=nidmm__pb2.SetAttributeViSessionResponse.SerializeToString,
            ),
            'SetAttributeViString': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAttributeViString,
                    request_deserializer=nidmm__pb2.SetAttributeViStringRequest.FromString,
                    response_serializer=nidmm__pb2.SetAttributeViStringResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nidmm_grpc.NiDmm', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NiDmm(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Abort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Abort',
            nidmm__pb2.AbortRequest.SerializeToString,
            nidmm__pb2.AbortResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViBoolean(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/CheckAttributeViBoolean',
            nidmm__pb2.CheckAttributeViBooleanRequest.SerializeToString,
            nidmm__pb2.CheckAttributeViBooleanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViInt32(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/CheckAttributeViInt32',
            nidmm__pb2.CheckAttributeViInt32Request.SerializeToString,
            nidmm__pb2.CheckAttributeViInt32Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViReal64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/CheckAttributeViReal64',
            nidmm__pb2.CheckAttributeViReal64Request.SerializeToString,
            nidmm__pb2.CheckAttributeViReal64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/CheckAttributeViSession',
            nidmm__pb2.CheckAttributeViSessionRequest.SerializeToString,
            nidmm__pb2.CheckAttributeViSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CheckAttributeViString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/CheckAttributeViString',
            nidmm__pb2.CheckAttributeViStringRequest.SerializeToString,
            nidmm__pb2.CheckAttributeViStringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearError(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ClearError',
            nidmm__pb2.ClearErrorRequest.SerializeToString,
            nidmm__pb2.ClearErrorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ClearInterchangeWarnings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ClearInterchangeWarnings',
            nidmm__pb2.ClearInterchangeWarningsRequest.SerializeToString,
            nidmm__pb2.ClearInterchangeWarningsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Close(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Close',
            nidmm__pb2.CloseRequest.SerializeToString,
            nidmm__pb2.CloseResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureACBandwidth(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureACBandwidth',
            nidmm__pb2.ConfigureACBandwidthRequest.SerializeToString,
            nidmm__pb2.ConfigureACBandwidthResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureADCCalibration(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureADCCalibration',
            nidmm__pb2.ConfigureADCCalibrationRequest.SerializeToString,
            nidmm__pb2.ConfigureADCCalibrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureAutoZeroMode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureAutoZeroMode',
            nidmm__pb2.ConfigureAutoZeroModeRequest.SerializeToString,
            nidmm__pb2.ConfigureAutoZeroModeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureCableCompType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureCableCompType',
            nidmm__pb2.ConfigureCableCompTypeRequest.SerializeToString,
            nidmm__pb2.ConfigureCableCompTypeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureCurrentSource(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureCurrentSource',
            nidmm__pb2.ConfigureCurrentSourceRequest.SerializeToString,
            nidmm__pb2.ConfigureCurrentSourceResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureFixedRefJunction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureFixedRefJunction',
            nidmm__pb2.ConfigureFixedRefJunctionRequest.SerializeToString,
            nidmm__pb2.ConfigureFixedRefJunctionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureFrequencyVoltageRange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureFrequencyVoltageRange',
            nidmm__pb2.ConfigureFrequencyVoltageRangeRequest.SerializeToString,
            nidmm__pb2.ConfigureFrequencyVoltageRangeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureMeasCompleteDest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureMeasCompleteDest',
            nidmm__pb2.ConfigureMeasCompleteDestRequest.SerializeToString,
            nidmm__pb2.ConfigureMeasCompleteDestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureMeasCompleteSlope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureMeasCompleteSlope',
            nidmm__pb2.ConfigureMeasCompleteSlopeRequest.SerializeToString,
            nidmm__pb2.ConfigureMeasCompleteSlopeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureMeasurementAbsolute(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureMeasurementAbsolute',
            nidmm__pb2.ConfigureMeasurementAbsoluteRequest.SerializeToString,
            nidmm__pb2.ConfigureMeasurementAbsoluteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureMeasurementDigits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureMeasurementDigits',
            nidmm__pb2.ConfigureMeasurementDigitsRequest.SerializeToString,
            nidmm__pb2.ConfigureMeasurementDigitsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureMultiPoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureMultiPoint',
            nidmm__pb2.ConfigureMultiPointRequest.SerializeToString,
            nidmm__pb2.ConfigureMultiPointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureOffsetCompOhms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureOffsetCompOhms',
            nidmm__pb2.ConfigureOffsetCompOhmsRequest.SerializeToString,
            nidmm__pb2.ConfigureOffsetCompOhmsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureOpenCableCompValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureOpenCableCompValues',
            nidmm__pb2.ConfigureOpenCableCompValuesRequest.SerializeToString,
            nidmm__pb2.ConfigureOpenCableCompValuesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigurePowerLineFrequency(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigurePowerLineFrequency',
            nidmm__pb2.ConfigurePowerLineFrequencyRequest.SerializeToString,
            nidmm__pb2.ConfigurePowerLineFrequencyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureRTDCustom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureRTDCustom',
            nidmm__pb2.ConfigureRTDCustomRequest.SerializeToString,
            nidmm__pb2.ConfigureRTDCustomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureRTDType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureRTDType',
            nidmm__pb2.ConfigureRTDTypeRequest.SerializeToString,
            nidmm__pb2.ConfigureRTDTypeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureSampleTriggerSlope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureSampleTriggerSlope',
            nidmm__pb2.ConfigureSampleTriggerSlopeRequest.SerializeToString,
            nidmm__pb2.ConfigureSampleTriggerSlopeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureShortCableCompValues(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureShortCableCompValues',
            nidmm__pb2.ConfigureShortCableCompValuesRequest.SerializeToString,
            nidmm__pb2.ConfigureShortCableCompValuesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureThermistorCustom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureThermistorCustom',
            nidmm__pb2.ConfigureThermistorCustomRequest.SerializeToString,
            nidmm__pb2.ConfigureThermistorCustomResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureThermistorType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureThermistorType',
            nidmm__pb2.ConfigureThermistorTypeRequest.SerializeToString,
            nidmm__pb2.ConfigureThermistorTypeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureThermocouple(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureThermocouple',
            nidmm__pb2.ConfigureThermocoupleRequest.SerializeToString,
            nidmm__pb2.ConfigureThermocoupleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureTransducerType(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureTransducerType',
            nidmm__pb2.ConfigureTransducerTypeRequest.SerializeToString,
            nidmm__pb2.ConfigureTransducerTypeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureTrigger',
            nidmm__pb2.ConfigureTriggerRequest.SerializeToString,
            nidmm__pb2.ConfigureTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureTriggerSlope(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureTriggerSlope',
            nidmm__pb2.ConfigureTriggerSlopeRequest.SerializeToString,
            nidmm__pb2.ConfigureTriggerSlopeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureWaveformAcquisition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureWaveformAcquisition',
            nidmm__pb2.ConfigureWaveformAcquisitionRequest.SerializeToString,
            nidmm__pb2.ConfigureWaveformAcquisitionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConfigureWaveformCoupling(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ConfigureWaveformCoupling',
            nidmm__pb2.ConfigureWaveformCouplingRequest.SerializeToString,
            nidmm__pb2.ConfigureWaveformCouplingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Control(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Control',
            nidmm__pb2.ControlRequest.SerializeToString,
            nidmm__pb2.ControlResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Disable',
            nidmm__pb2.DisableRequest.SerializeToString,
            nidmm__pb2.DisableResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExportAttributeConfigurationBuffer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ExportAttributeConfigurationBuffer',
            nidmm__pb2.ExportAttributeConfigurationBufferRequest.SerializeToString,
            nidmm__pb2.ExportAttributeConfigurationBufferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExportAttributeConfigurationFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ExportAttributeConfigurationFile',
            nidmm__pb2.ExportAttributeConfigurationFileRequest.SerializeToString,
            nidmm__pb2.ExportAttributeConfigurationFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Fetch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Fetch',
            nidmm__pb2.FetchRequest.SerializeToString,
            nidmm__pb2.FetchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FetchMultiPoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/FetchMultiPoint',
            nidmm__pb2.FetchMultiPointRequest.SerializeToString,
            nidmm__pb2.FetchMultiPointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FetchWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/FetchWaveform',
            nidmm__pb2.FetchWaveformRequest.SerializeToString,
            nidmm__pb2.FetchWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApertureTimeInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetApertureTimeInfo',
            nidmm__pb2.GetApertureTimeInfoRequest.SerializeToString,
            nidmm__pb2.GetApertureTimeInfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViBoolean(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetAttributeViBoolean',
            nidmm__pb2.GetAttributeViBooleanRequest.SerializeToString,
            nidmm__pb2.GetAttributeViBooleanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViInt32(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetAttributeViInt32',
            nidmm__pb2.GetAttributeViInt32Request.SerializeToString,
            nidmm__pb2.GetAttributeViInt32Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViReal64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetAttributeViReal64',
            nidmm__pb2.GetAttributeViReal64Request.SerializeToString,
            nidmm__pb2.GetAttributeViReal64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetAttributeViSession',
            nidmm__pb2.GetAttributeViSessionRequest.SerializeToString,
            nidmm__pb2.GetAttributeViSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAttributeViString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetAttributeViString',
            nidmm__pb2.GetAttributeViStringRequest.SerializeToString,
            nidmm__pb2.GetAttributeViStringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAutoRangeValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetAutoRangeValue',
            nidmm__pb2.GetAutoRangeValueRequest.SerializeToString,
            nidmm__pb2.GetAutoRangeValueResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetCalDateAndTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetCalDateAndTime',
            nidmm__pb2.GetCalDateAndTimeRequest.SerializeToString,
            nidmm__pb2.GetCalDateAndTimeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChannelName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetChannelName',
            nidmm__pb2.GetChannelNameRequest.SerializeToString,
            nidmm__pb2.GetChannelNameResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetDevTemp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetDevTemp',
            nidmm__pb2.GetDevTempRequest.SerializeToString,
            nidmm__pb2.GetDevTempResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetError(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetError',
            nidmm__pb2.GetErrorRequest.SerializeToString,
            nidmm__pb2.GetErrorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetErrorMessage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetErrorMessage',
            nidmm__pb2.GetErrorMessageRequest.SerializeToString,
            nidmm__pb2.GetErrorMessageResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetExtCalRecommendedInterval(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetExtCalRecommendedInterval',
            nidmm__pb2.GetExtCalRecommendedIntervalRequest.SerializeToString,
            nidmm__pb2.GetExtCalRecommendedIntervalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLastCalTemp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetLastCalTemp',
            nidmm__pb2.GetLastCalTempRequest.SerializeToString,
            nidmm__pb2.GetLastCalTempResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMeasurementPeriod(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetMeasurementPeriod',
            nidmm__pb2.GetMeasurementPeriodRequest.SerializeToString,
            nidmm__pb2.GetMeasurementPeriodResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNextCoercionRecord(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetNextCoercionRecord',
            nidmm__pb2.GetNextCoercionRecordRequest.SerializeToString,
            nidmm__pb2.GetNextCoercionRecordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNextInterchangeWarning(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetNextInterchangeWarning',
            nidmm__pb2.GetNextInterchangeWarningRequest.SerializeToString,
            nidmm__pb2.GetNextInterchangeWarningResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSelfCalSupported(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/GetSelfCalSupported',
            nidmm__pb2.GetSelfCalSupportedRequest.SerializeToString,
            nidmm__pb2.GetSelfCalSupportedResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ImportAttributeConfigurationBuffer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ImportAttributeConfigurationBuffer',
            nidmm__pb2.ImportAttributeConfigurationBufferRequest.SerializeToString,
            nidmm__pb2.ImportAttributeConfigurationBufferResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ImportAttributeConfigurationFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ImportAttributeConfigurationFile',
            nidmm__pb2.ImportAttributeConfigurationFileRequest.SerializeToString,
            nidmm__pb2.ImportAttributeConfigurationFileResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Init(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Init',
            nidmm__pb2.InitRequest.SerializeToString,
            nidmm__pb2.InitResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitWithOptions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/InitWithOptions',
            nidmm__pb2.InitWithOptionsRequest.SerializeToString,
            nidmm__pb2.InitWithOptionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Initiate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Initiate',
            nidmm__pb2.InitiateRequest.SerializeToString,
            nidmm__pb2.InitiateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InvalidateAllAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/InvalidateAllAttributes',
            nidmm__pb2.InvalidateAllAttributesRequest.SerializeToString,
            nidmm__pb2.InvalidateAllAttributesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsOverRange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/IsOverRange',
            nidmm__pb2.IsOverRangeRequest.SerializeToString,
            nidmm__pb2.IsOverRangeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IsUnderRange(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/IsUnderRange',
            nidmm__pb2.IsUnderRangeRequest.SerializeToString,
            nidmm__pb2.IsUnderRangeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PerformOpenCableComp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/PerformOpenCableComp',
            nidmm__pb2.PerformOpenCableCompRequest.SerializeToString,
            nidmm__pb2.PerformOpenCableCompResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PerformShortCableComp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/PerformShortCableComp',
            nidmm__pb2.PerformShortCableCompRequest.SerializeToString,
            nidmm__pb2.PerformShortCableCompResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Read(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Read',
            nidmm__pb2.ReadRequest.SerializeToString,
            nidmm__pb2.ReadResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadMultiPoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ReadMultiPoint',
            nidmm__pb2.ReadMultiPointRequest.SerializeToString,
            nidmm__pb2.ReadMultiPointResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ReadStatus',
            nidmm__pb2.ReadStatusRequest.SerializeToString,
            nidmm__pb2.ReadStatusResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadWaveform(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ReadWaveform',
            nidmm__pb2.ReadWaveformRequest.SerializeToString,
            nidmm__pb2.ReadWaveformResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/Reset',
            nidmm__pb2.ResetRequest.SerializeToString,
            nidmm__pb2.ResetResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetInterchangeCheck(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ResetInterchangeCheck',
            nidmm__pb2.ResetInterchangeCheckRequest.SerializeToString,
            nidmm__pb2.ResetInterchangeCheckResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetWithDefaults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/ResetWithDefaults',
            nidmm__pb2.ResetWithDefaultsRequest.SerializeToString,
            nidmm__pb2.ResetWithDefaultsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevisionQuery(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/RevisionQuery',
            nidmm__pb2.RevisionQueryRequest.SerializeToString,
            nidmm__pb2.RevisionQueryResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SelfCal(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/SelfCal',
            nidmm__pb2.SelfCalRequest.SerializeToString,
            nidmm__pb2.SelfCalResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SelfTest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/SelfTest',
            nidmm__pb2.SelfTestRequest.SerializeToString,
            nidmm__pb2.SelfTestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendSoftwareTrigger(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/SendSoftwareTrigger',
            nidmm__pb2.SendSoftwareTriggerRequest.SerializeToString,
            nidmm__pb2.SendSoftwareTriggerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViBoolean(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/SetAttributeViBoolean',
            nidmm__pb2.SetAttributeViBooleanRequest.SerializeToString,
            nidmm__pb2.SetAttributeViBooleanResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViInt32(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/SetAttributeViInt32',
            nidmm__pb2.SetAttributeViInt32Request.SerializeToString,
            nidmm__pb2.SetAttributeViInt32Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViReal64(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/SetAttributeViReal64',
            nidmm__pb2.SetAttributeViReal64Request.SerializeToString,
            nidmm__pb2.SetAttributeViReal64Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/SetAttributeViSession',
            nidmm__pb2.SetAttributeViSessionRequest.SerializeToString,
            nidmm__pb2.SetAttributeViSessionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAttributeViString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nidmm_grpc.NiDmm/SetAttributeViString',
            nidmm__pb2.SetAttributeViStringRequest.SerializeToString,
            nidmm__pb2.SetAttributeViStringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
